@@ -143,8 +143,30 @@ std::string Options::selectRole(
     return selectedRole;
 }
 
-std::expected<std::array<std::string, 6>, std::string>
-Options::getOptions(int argc, char** argv) {
+std::string Options::receiveMultiLines() {
+    std::cout << "Note: You may input multiple lines and use the Enter key to start a new line.\n"
+                 "      Restricted by a terminal's mechanism for handling some keys like\n"
+                 "      Backspace and arrow keys, it is recommended that you write contents\n"
+                 "      in a text editor and paste the text here.\n"
+                 "      Once you finish inputting, please input \"exit\" in a new line\n"
+                 "      and press the Enter key.\n";
+
+    std::string inputtedText;
+    std::string inputtedLine;
+
+    while (std::getline(std::cin, inputtedLine)) {
+        if (inputtedLine == "exit") {
+            break;
+        }
+
+        inputtedText += inputtedLine;
+        inputtedText += '\n';
+    }
+
+    return inputtedText;
+}
+
+std::array<std::string, 6> Options::getOptions(int argc, char** argv) {
     // All available options.
     std::vector<std::string> options = {
         "--add-key",  // Add or update an API key.
@@ -298,20 +320,9 @@ Options::getOptions(int argc, char** argv) {
                 std::string roleInstruction;
                 std::getline(std::cin, roleInstruction);
 
-                std::cout << "Please write detailed instructions for the role.\n"
-                             "You may input multiple lines and use the Enter key to start a new line.\n"
-                             "For exiting without inputting anything, just press the Enter key.\n"
-                             "If you have inputted something, please press the Enter key twice for exiting.\n";
-                std::string detailedInstructions;
-                std::string detailedInstructionsLine;
-                while (std::getline(std::cin, detailedInstructionsLine)) {
-                    if (detailedInstructionsLine.empty()) {
-                        break;
-                    }
+                std::cout << "Please write detailed instructions for the role.\n";
 
-                    detailedInstructions += detailedInstructionsLine;
-                    detailedInstructions += '\n';
-                }
+                std::string detailedInstructions = receiveMultiLines();
 
                 if (!roleName.empty() && !detailedInstructions.empty()) {
                     optionValue += roleName;
@@ -565,20 +576,9 @@ Options::getOptions(int argc, char** argv) {
 
         else if (option == "-content") {
             if (optionValue.empty()) {
-                std::cout << "Please give specific instructions for AI.\n"
-                             "You may input multiple lines and use the Enter key to start a new line.\n"
-                             "For exiting without inputting anything, just press the Enter key.\n"
-                             "If you have inputted something, please press the Enter key twice for exiting.\n";
-                std::string supposedContent;
+                std::cout << "Please give specific instructions for AI.\n";
 
-                while (std::getline(std::cin, supposedContent)) {
-                    if (supposedContent.empty()) {
-                        break;
-                    }
-
-                    optionValue += supposedContent;
-                    optionValue += '\n';
-                }
+                optionValue = receiveMultiLines();
             }
 
             if (optionValue.empty()) {
@@ -599,18 +599,6 @@ Options::getOptions(int argc, char** argv) {
         }
     }
 
-    if (connectionKey.empty()) {
-        return std::unexpected("No API connection is performed, because no key is found.");
-    }
-
-    if (connectionModel.empty()) {
-        return std::unexpected("No API connection is performed, because no model is found.");
-    }
-
-    if (connectionContent.empty()) {
-        return std::unexpected("No API connection is performed, because there is no specific instructions.");
-    }
-
     return std::array{
         connectionProvider,
         connectionKey,
